Renamed urldata.h members 'ioctl*' to 'ioctrl*' due to
authorGisle Vanem <gvanem@broadpark.no>
Fri, 26 Nov 2004 14:57:01 +0000 (14:57 +0000)
committerGisle Vanem <gvanem@broadpark.no>
Fri, 26 Nov 2004 14:57:01 +0000 (14:57 +0000)
clash with djgpp ioctl() macro in setup.h.

lib/transfer.c
lib/url.c
lib/urldata.h

index 0177845..c0fea34 100644 (file)
@@ -211,16 +211,16 @@ CURLcode Curl_readrewind(struct connectdata *conn)
      (data->set.httpreq == HTTPREQ_POST_FORM))
     ; /* do nothing */
   else {
-    if(data->set.ioctl) {
+    if(data->set.ioctrl) {
       curlioerr err;
 
-      err = data->set.ioctl(data, CURLIOCMD_RESTARTREAD,
-                            data->set.ioctl_client);
-      infof(data, "the ioctl callback returned %d\n", (int)err);
+      err = data->set.ioctrl(data, CURLIOCMD_RESTARTREAD,
+                             data->set.ioctrl_client);
+      infof(data, "the ioctrl callback returned %d\n", (int)err);
 
       if(err) {
         /* FIXME: convert to a human readable error message */
-        failf(data, "ioctl callback returned error %d\n", (int)err);
+        failf(data, "ioctrl callback returned error %d\n", (int)err);
         return CURLE_SEND_FAIL_REWIND;
       }
     }
index cfc7911..21531da 100644 (file)
--- a/lib/url.c
+++ b/lib/url.c
@@ -1105,13 +1105,13 @@ CURLcode Curl_setopt(struct SessionHandle *data, CURLoption option, ...)
     /*
      * I/O control callback. Might be NULL.
      */
-    data->set.ioctl = va_arg(param, curl_ioctl_callback);
+    data->set.ioctrl = va_arg(param, curl_ioctl_callback);
     break;
   case CURLOPT_IOCTLDATA:
     /*
      * I/O control data pointer. Might be NULL.
      */
-    data->set.ioctl_client = va_arg(param, void *);
+    data->set.ioctrl_client = va_arg(param, void *);
     break;
   case CURLOPT_SSLCERT:
     /*
index 903f47a..eefa605 100644 (file)
@@ -847,9 +847,9 @@ struct UserDefined {
   curl_read_callback fread;          /* function that reads the input */
   curl_progress_callback fprogress;  /* function for progress information */
   curl_debug_callback fdebug;      /* function that write informational data */
-  curl_ioctl_callback ioctl;       /* function for I/O control */
+  curl_ioctl_callback ioctrl;      /* function for I/O control */
   void *progress_client; /* pointer to pass to the progress callback */
-  void *ioctl_client;   /* pointer to pass to the ioctl callback */
+  void *ioctrl_client;  /* pointer to pass to the ioctrl callback */
   long timeout;         /* in seconds, 0 means no timeout */
   long connecttimeout;  /* in seconds, 0 means no timeout */
   long ftp_response_timeout; /* in seconds, 0 means no timeout */